@@ -28,6 +28,7 @@
 #include <string.h>
 
 #include "config.h"
+#include "htmlcluev.h"
 #include "htmlcolor.h"
 #include "htmlengine.h"
 #include "htmlimage.h"
@@ -221,6 +222,7 @@ get_body (HTMLEngine *e)
 	gchar *bg;
 	gchar *bg_image;
 	gchar *link;
+	char *dir = NULL;
 	gchar *lm, *rm, *tm, *bm;
 	gchar *url = NULL;
 
@@ -233,6 +235,12 @@ get_body (HTMLEngine *e)
 						     (e->widget, ((HTMLImagePointer *) e->bgPixmapPtr)->url))
 		: g_strdup ("");
 	g_free (url);
+	if (HTML_CLUEV (e->clue)->dir != HTML_DIRECTION_DERIVED) {
+		if (HTML_CLUEV (e->clue)->dir == HTML_DIRECTION_RTL)
+			dir = " DIR=RTL";
+		else
+			dir = " DIR=LTR";
+	}
 
 	lm = e->leftBorder != LEFT_BORDER ? g_strdup_printf (" LEFTMARGIN=\"%d\"", e->leftBorder) : g_strdup ("");
 	rm = e->rightBorder != RIGHT_BORDER ? g_strdup_printf (" RIGHTMARGIN=\"%d\"", e->rightBorder) : g_strdup ("");
@@ -385,17 +393,22 @@ html_engine_save_buffer_receiver (const HTMLEngine *engine,
 	return TRUE;
 }
 	
-void
-html_engine_save_buffer_free (HTMLEngineSaveState *state)
+char *
+html_engine_save_buffer_free (HTMLEngineSaveState *state, gboolean free_string)
 {
 	GString *string;
+	char *rv = NULL;
 
-	g_return_if_fail (state != NULL);
+	g_return_val_if_fail (state != NULL, NULL);
 	string = (GString *)state->user_data;
 
-	g_string_free (string, TRUE);
+	if (!free_string)
+		rv = string->str;
+	g_string_free (string, free_string);
 
 	g_free (state);
+
+	return rv;
 }
 
 guchar *
