@@ -467,10 +467,10 @@ save (HTMLObject *s,
 		    !html_engine_save_output_buffer (state,
 						     html_engine_save_buffer_peek_text (buffer),
 						     html_engine_save_buffer_peek_text_bytes (buffer))) {
-			html_engine_save_buffer_free (buffer);
+			html_engine_save_buffer_free (buffer, TRUE);
 			return FALSE;
 		}
-		html_engine_save_buffer_free (buffer);
+		html_engine_save_buffer_free (buffer, TRUE);
 	} else {
 		HTMLEngine *e = GTK_HTML (iframe->html)->engine;
 
@@ -520,10 +520,10 @@ save_plain (HTMLObject *s,
 		    !html_engine_save_output_buffer (state,
 						     html_engine_save_buffer_peek_text (buffer),
 						     html_engine_save_buffer_peek_text_bytes (buffer))) {
-			html_engine_save_buffer_free (buffer);
+			html_engine_save_buffer_free (buffer, TRUE);
 			return FALSE;
 		}
-		html_engine_save_buffer_free (buffer);
+		html_engine_save_buffer_free (buffer, TRUE);
 	}
 
 	return TRUE;
@@ -616,7 +616,9 @@ html_iframe_init (HTMLIFrame *iframe,
 			handle = gtk_html_begin (new_html);
 			g_signal_emit_by_name (parent_html->engine, "url_requested", src, handle);
 		}
-	}
+	} else
+		gtk_html_load_empty (new_html);
+
 	new_html->engine->clue->parent = HTML_OBJECT (iframe);
 	
 #if 0
